function pd = mphparticle(model,varargin)
% MPHPARTICLE  Evaluate expressions on particle and ray trajectories
%
%   PD = MPHPARTICLE(model) returns particle position and particle
%   velocity at all time steps stored in the first particle dataset.
%
%   PD = MPHPARTICLE(model,'EXPR',{E1,...,EN},...) returns particle
%   position, particle velocity and expressions e1, ..., en evaluated on
%   particle or ray trajectories.
%
%   Valid property/value pairs include:
%   Property       Value/{Default}        Description
%   -----------------------------------------------------------------------
%   expr         String | Cell array      Expressions to evaluate
%                {''}
%   dataonly     {'off'} | 'on'           Return only expression values
%   dataset      String {''}              Data set tag
%   t            Double array {[]}        Time for evaluation
%   solnum       Positive integer array | Inner solution for evaluation
%                'end' | {'all'}
%   outersolnum  Positive integer {1} |	  Solution number for parametric
%                                         sweep
%   times        {'on'} | 'off'           Return times
%   velocities   {'on'} | 'off'           Return velocities
%
%   PD is a structure with the following fields:
%      p           - Position of the particles
%      v           - Velocity of the particles
%      d#          - Result of evaluation #
%      t           - Time for evaluation
%      expr        - Evaluated expressions
%      unit        - Unit of evaluations
%
%   Note that MPHPARTICLE only evaluates expressions using particle
%   and ray data sets.
%
%   Example:
%     % Load the model laminar_mixer_particle from the Model Library:
%     model = mphopen('laminar_mixer_particle');
%
%     % Extract the particle positions and particle velocities along the
%     % computed trajectories at every time steps stored in the model:
%     pd = mphparticle(model)
%
%     % Evaluate the pressure and the fluid velocity magnitude value along
%     % the particle trajectories at t=2.65 sec., extract only the data:
%     pd = mphparticle(model,'expr',{'p','spf.U'},'t',2.65,'dataonly','on')
%
%   See also: mphray, mpheval, mphevalpoint, mphint2, mphinterp

%   Copyright 2012-2017 COMSOL
